==> petljadoc-1.4.3-py3-none-any.whl: petljadoc/runestone_ext/blockly/js/karelBlocks-i18n.sr-Cyrl.js <==
$.i18n().load({
    "sr-Cyrl": {
        "move_forward": "корак напред",
        "move_forward_tooltip": "Робот се помера једно поље у напред.",
        "move_back": "корак назад",
        "move_back_tooltip": "Робот се помера једно поље у назад.",
        "turn_left": "скрени лево",
        "turn_left_tooltip": "Робот се окреће на лево.",
        "turn_right": "скрени десно",
        "turn_right_tooltip": "Робот се окреће на десно.",
        "turn_around": "окрени полукружно",
        "turn_around_tooltip": "Робот се окреће на десно.",
        "pick_up": "узми",
        "pick_up_tooltip": "Робот узима лопту са поља на коме се налази.",
        "drop_off": "остави",
        "drop_off_tooltip": "Робот оставља лопту.",
        "can_move": "робот може напред",
        "can_move_tooltip": "Робот одговара на питање да ли може да направи корак напред.",
        "balls_present": "постоји лоптица",
        "balls_present_tooltip": "Робот одговара на питање да ли има лоптица на пољу на коме се налази.",
        "has_balls": "робот има лоптицу",
        "has_balls_tooltip": "Да ли робот има лоптице код себе.",
        "count_balls": "колико лоптица има на пољу",
        "count_balls_tooltip": "Робот одговара на питање колико лоптица има на пољу на коме се налази.",
        "count_balls_on_hand": "колико лоптица има код робота",
        "count_balls_on_hand_tooltip": "Робот одговара на питање колико лоптица има код себе.",
        "karel_controls_whileUntil": "Понављај док %1",
        "robot_has_ball": "робот има лопту",
        "balls_present_on_field": "лоптице на пољу",
        "robot_can_move_forward": "робот може напред",
        "variables_set": "Постави %1 на %2",
        "number_prompt": "Питај ",
        "KarelCommands": "Наредбе роботу",
        "BeginnerKarelCommands": "Наредбе роботу",
        "KarelStraightLineCommands": "Наредбе роботу",
        "KarelBrain": "Питај робота",
        "K_Values": "Вредности",
        "K_Branching": "Гранање",
        "KarelBranching": "Гранање робот",
        "K_Vars": "Променљиве",
        "K_Loops": "Петље",
        "KarelLoops": "Петље робот",
        "K_Logic": "Логички оператори",
        "Arithmetic": "Аритметикa",
        "KarelSays": "Поруке роботу",
        "K_AskUser": "Помози роботу"
    }
})

==> petljadoc-1.4.5-py3-none-any.whl: petljadoc/runestone_ext/blockly/js/karelBlocks-i18n.sr-Cyrl.js <==
$.i18n().load({
    "sr-Cyrl": {
        "move_forward": "корак напред",
        "move_forward_tooltip": "Робот се помера једно поље у напред.",
        "move_back": "корак назад",
        "move_back_tooltip": "Робот се помера једно поље у назад.",
        "turn_left": "окрени се лево",
        "turn_left_tooltip": "Робот се окреће на лево.",
        "turn_right": "окрени се десно",
        "turn_right_tooltip": "Робот се окреће на десно.",
        "turn_around": "окрени полукружно",
        "turn_around_tooltip": "Робот се окреће на десно.",
        "pick_up": "узми",
        "pick_up_tooltip": "Робот узима лопту са поља на коме се налази.",
        "drop_off": "остави",
        "drop_off_tooltip": "Робот оставља лопту.",
        "can_move": "робот може напред",
        "can_move_tooltip": "Робот одговара на питање да ли може да направи корак напред.",
        "balls_present": "постоји лоптица",
        "balls_present_tooltip": "Робот одговара на питање да ли има лоптица на пољу на коме се налази.",
        "has_balls": "робот има лоптицу",
        "has_balls_tooltip": "Да ли робот има лоптице код себе.",
        "count_balls": "колико лоптица има на пољу",
        "count_balls_tooltip": "Робот одговара на питање колико лоптица има на пољу на коме се налази.",
        "count_balls_on_hand": "колико лоптица има код робота",
        "count_balls_on_hand_tooltip": "Робот одговара на питање колико лоптица има код себе.",
        "karel_controls_whileUntil": "Понављај док %1",
        "robot_has_ball": "робот има лопту",
        "balls_present_on_field": "лоптице на пољу",
        "robot_can_move_forward": "робот може напред",
        "variables_set": "Постави %1 на %2",
        "number_prompt": "Питај ",
        "KarelCommands": "Наредбе роботу",
        "BeginnerKarelCommands": "Наредбе роботу",
        "KarelStraightLineCommands": "Наредбе роботу",
        "KarelBrain": "Питај робота",
        "K_Values": "Вредности",
        "K_Branching": "Гранање",
        "KarelBranching": "Гранање робот",
        "K_Vars": "Променљиве",
        "K_Loops": "Петље",
        "KarelLoops": "Петље робот",
        "K_Logic": "Логички оператори",
        "Arithmetic": "Аритметикa",
        "KarelSays": "Поруке роботу",
        "K_AskUser": "Помози роботу"
    }
})
